from django.db import models
from django.utils import timezone


class Artist(models.Model):
    artist_name = models.TextField()
    birth_name = models.TextField(blank=True)
    monthly_listeners = models.IntegerField()
    bio = models.TextField(blank=True)

    def __str__(self):
        return '{} [{}]'.format(self.artist_name, self.birth_name)


class Album(models.Model):
    album_name = models.TextField()
    description = models.TextField()
    artist = models.ForeignKey(Artist, on_delete=models.CASCADE)
    release_date = models.DateTimeField()
    label = models.TextField(blank=True)
    song_count = models.IntegerField(null=True)

    def __str__(self):
        return '{} [{}], {} {}'.format(self.album_name, self.release_date, self.description, self.label)

class Song(models.Model):
    song_title = models.TextField()
    artist = models.ForeignKey(Artist, on_delete=models.CASCADE)
    album = models.ForeignKey(Album, on_delete=models.CASCADE)
    song_length = models.FloatField()
    music_video = models.BooleanField(null=True)
    lyrics = models.TextField(blank=True)

    def __str__(self):
        return '{}'.format(self.song_title)
